m_librarian.db module — Документация m_Librarian 0.1.2

# m_librarian.db module

class `m_librarian.db.` `Author`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  `addBook`(obj)
  `books`
  `count`
  `count_idx` = <sqlobject.index.SODatabaseIndex object>
  `full_name_idx` = <sqlobject.index.SODatabaseIndex object>
  `fullname`
  `j` = author
  `misc_name`
  `name`
  `q` = author
  `removeBook`(obj)
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'count': <IntCol b5de096cL count>, 'misc_name': <UnicodeCol b5de0eccL misc_name>, 'name': <UnicodeCol b5dc602cL name>, 'surname': <UnicodeCol b5dc5f2cL surname>}
    `columnList` = [<SOUnicodeCol surname not null>, <SOUnicodeCol name not null>, <SOUnicodeCol misc_name not null>, <SOIntCol count not null>]
    `columns` = {'count': <SOIntCol count not null>, 'misc_name': <SOUnicodeCol misc_name not null>, 'name': <SOUnicodeCol name not null>, 'surname': <SOUnicodeCol surname not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5d8c1acL {'unique': True, 'name': 'full_name_idx', 'columns': (<UnicodeCol b5dc5f2cL surname>, <UnicodeCol b5dc602cL name>, <UnicodeCol b5de0eccL misc_name>)}>, <DatabaseIndex b5d8c1ecL {'name': 'count_idx', 'columns': (<IntCol b5de096cL count>,)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      псевдоним класса `m_librarian.db.Author`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'author'
  `surname`

class `m_librarian.db.` `Book`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  `addAuthor`(obj)
  `addGenre`(obj)
  `archive`
  `archive_file_idx` = <sqlobject.index.SODatabaseIndex object>
  `archive_idx` = <sqlobject.index.SODatabaseIndex object>
  `authors`
  `date`
  `date_idx` = <sqlobject.index.SODatabaseIndex object>
  `deleted`
  `deleted_idx` = <sqlobject.index.SODatabaseIndex object>
  `extension`
  `extensionID`
  `extension_idx` = <sqlobject.index.SODatabaseIndex object>
  `file`
  `file_idx` = <sqlobject.index.SODatabaseIndex object>
  `genres`
  `j` = book
  `language`
  `languageID`
  `language_idx` = <sqlobject.index.SODatabaseIndex object>
  `lib_id`
  `q` = book
  `removeAuthor`(obj)
  `removeGenre`(obj)
  `ser_no`
  `ser_no_idx` = <sqlobject.index.SODatabaseIndex object>
  `series`
  `series_idx` = <sqlobject.index.SODatabaseIndex object>
  `size`
  `size_idx` = <sqlobject.index.SODatabaseIndex object>
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'archive': <StringCol b5d82c2cL archive>, 'date': <DateCol b5d9b46cL date>, 'deleted': <BoolCol b5d9b42cL deleted>, 'extensionID': <ForeignKey b5d9b44cL extension>, 'file': <UnicodeCol b5d82f0cL file>, 'languageID': <ForeignKey b5d9b48cL language>, 'lib_id': <StringCol b5d9b40cL lib_id>, 'ser_no': <IntCol b5d82c4cL ser_no>, 'series': <UnicodeCol b5d82f2cL series>, 'size': <IntCol b5d9b3ccL size>, 'title': <UnicodeCol b5d9b2acL title>}
    `columnList` = [<SOUnicodeCol title not null>, <SOUnicodeCol series not null>, <SOIntCol ser_no>, <SOStringCol archive not null>, <SOUnicodeCol file not null>, <SOIntCol size not null>, <SOStringCol lib_id not null>, <SOBoolCol deleted not null>, <SOForeignKey extensionID connected to Extension not null>, <SODateCol date not null>, <SOForeignKey languageID connected to Language>]
    `columns` = {'archive': <SOStringCol archive not null>, 'date': <SODateCol date not null>, 'deleted': <SOBoolCol deleted not null>, 'extensionID': <SOForeignKey extensionID connected to Extension not null>, 'file': <SOUnicodeCol file not null>, 'languageID': <SOForeignKey languageID connected to Language>, 'lib_id': <SOStringCol lib_id not null>, 'ser_no': <SOIntCol ser_no>, 'series': <SOUnicodeCol series not null>, 'size': <SOIntCol size not null>, 'title': <SOUnicodeCol title not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5d9b4acL {'name': 'title_idx', 'columns': (<UnicodeCol b5d9b2acL title>,)}>, <DatabaseIndex b5d9b3ecL {'name': 'series_idx', 'columns': (<UnicodeCol b5d82f2cL series>,)}>, <DatabaseIndex b5d9b4ccL {'name': 'ser_no_idx', 'columns': (<IntCol b5d82c4cL ser_no>,)}>, <DatabaseIndex b5d9b4ecL {'name': 'archive_idx', 'columns': (<StringCol b5d82c2cL archive>,)}>, <DatabaseIndex b5d9b50cL {'unique': True, 'name': 'archive_file_idx', 'columns': (<StringCol b5d82c2cL archive>, <UnicodeCol b5d82f0cL file>)}>, <DatabaseIndex b5d9b52cL {'name': 'file_idx', 'columns': (<UnicodeCol b5d82f0cL file>,)}>, <DatabaseIndex b5d9b54cL {'name': 'size_idx', 'columns': (<IntCol b5d9b3ccL size>,)}>, <DatabaseIndex b5d9b58cL {'name': 'deleted_idx', 'columns': (<BoolCol b5d9b42cL deleted>,)}>, <DatabaseIndex b5d9b5ccL {'name': 'extension_idx', 'columns': (<ForeignKey b5d9b44cL extension>,)}>, <DatabaseIndex b5d9b60cL {'name': 'date_idx', 'columns': (<DateCol b5d9b46cL date>,)}>, <DatabaseIndex b5d9b64cL {'name': 'language_idx', 'columns': (<ForeignKey b5d9b48cL language>,)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>, <sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>, <sqlobject.joins.SORelatedJoin object>]
    `soClass`

      псевдоним класса `m_librarian.db.Book`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'book'
  `title`
  `title_idx` = <sqlobject.index.SODatabaseIndex object>

class `m_librarian.db.` `Extension`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `count`
  `count_idx` = <sqlobject.index.SODatabaseIndex object>
  `j` = extension
  `name`
  `q` = extension
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'count': <IntCol b5da734cL count>, 'name': <UnicodeCol b5da72ccL name>}
    `columnList` = [<SOUnicodeCol name not null>, <SOIntCol count not null>]
    `columns` = {'count': <SOIntCol count not null>, 'name': <SOUnicodeCol name not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5da738cL {'name': 'count_idx', 'columns': (<IntCol b5da734cL count>,)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      псевдоним класса `m_librarian.db.Extension`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'extension'

class `m_librarian.db.` `Genre`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  `addBook`(obj)
  `books`
  classmethod `byName`(val, connection=None)
  `count`
  `count_idx` = <sqlobject.index.SODatabaseIndex object>
  `j` = genre
  `name`
  `q` = genre
  `removeBook`(obj)
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'count': <IntCol b5da780cL count>, 'name': <UnicodeCol b5da778cL name>, 'title': <UnicodeCol b5da77ecL title>}
    `columnList` = [<SOUnicodeCol name not null>, <SOUnicodeCol title not null>, <SOIntCol count not null>]
    `columns` = {'count': <SOIntCol count not null>, 'name': <SOUnicodeCol name not null>, 'title': <SOUnicodeCol title not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5da77acL {'name': 'title_idx', 'columns': (<UnicodeCol b5da77ecL title>,)}>, <DatabaseIndex b5da786cL {'name': 'count_idx', 'columns': (<IntCol b5da780cL count>,)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      псевдоним класса `m_librarian.db.Genre`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'genre'
  `title`
  `title_idx` = <sqlobject.index.SODatabaseIndex object>

class `m_librarian.db.` `Language`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `count`
  `count_idx` = <sqlobject.index.SODatabaseIndex object>
  `j` = language
  `name`
  `q` = language
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'count': <IntCol b5da7facL count>, 'name': <UnicodeCol b5da7f8cL name>}
    `columnList` = [<SOUnicodeCol name not null>, <SOIntCol count not null>]
    `columns` = {'count': <SOIntCol count not null>, 'name': <SOUnicodeCol name not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5da7fccL {'name': 'count_idx', 'columns': (<IntCol b5da7facL count>,)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      псевдоним класса `m_librarian.db.Language`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'language'

class `m_librarian.db.` `AuthorBook`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  `author`
  `authorID`
  `author_idx` = <sqlobject.index.SODatabaseIndex object>
  `book`
  `bookID`
  `book_idx` = <sqlobject.index.SODatabaseIndex object>
  `j` = author_book
  `main_idx` = <sqlobject.index.SODatabaseIndex object>
  `q` = author_book
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'authorID': <ForeignKey b5d8cbacL author>, 'bookID': <ForeignKey b5d8cb8cL book>}
    `columnList` = [<SOForeignKey authorID connected to Author not null>, <SOForeignKey bookID connected to Book not null>]
    `columns` = {'authorID': <SOForeignKey authorID connected to Author not null>, 'bookID': <SOForeignKey bookID connected to Book not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5d8c3ecL {'name': 'author_idx', 'columns': (<ForeignKey b5d8cbacL author>,)}>, <DatabaseIndex b5d8cc0cL {'name': 'book_idx', 'columns': (<ForeignKey b5d8cb8cL book>,)}>, <DatabaseIndex b5d8cc4cL {'unique': True, 'name': 'main_idx', 'columns': (<ForeignKey b5d8cbacL author>, <ForeignKey b5d8cb8cL book>)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      псевдоним класса `m_librarian.db.AuthorBook`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'author_book'

class `m_librarian.db.` `BookGenre`(**kw)

  > Базовые классы: `sqlobject.main.SQLObject`

  `book`
  `bookID`
  `book_idx` = <sqlobject.index.SODatabaseIndex object>
  `genre`
  `genreID`
  `genre_idx` = <sqlobject.index.SODatabaseIndex object>
  `j` = book_genre
  `main_idx` = <sqlobject.index.SODatabaseIndex object>
  `q` = book_genre
  class `sqlmeta`(instance)

    > Базовые классы: `sqlobject.main.sqlmeta`

    `childName` = None
    `columnDefinitions` = {'bookID': <ForeignKey b5da1d6cL book>, 'genreID': <ForeignKey b5da1d0cL genre>}
    `columnList` = [<SOForeignKey bookID connected to Book not null>, <SOForeignKey genreID connected to Genre not null>]
    `columns` = {'bookID': <SOForeignKey bookID connected to Book not null>, 'genreID': <SOForeignKey genreID connected to Genre not null>}
    `idName` = 'id'
    `indexDefinitions` = [<DatabaseIndex b5da1c8cL {'name': 'book_idx', 'columns': (<ForeignKey b5da1d6cL book>,)}>, <DatabaseIndex b5da1becL {'name': 'genre_idx', 'columns': (<ForeignKey b5da1d0cL genre>,)}>, <DatabaseIndex b5da1cecL {'unique': True, 'name': 'main_idx', 'columns': (<ForeignKey b5da1d6cL book>, <ForeignKey b5da1d0cL genre>)}>]
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      псевдоним класса `m_librarian.db.BookGenre`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'book_genre'

`m_librarian.db.` `open_db`(db_uri=None)

`m_librarian.db.` `init_db`()

`m_librarian.db.` `insert_name`(table, name, **kw)

`m_librarian.db.` `insert_author`(surname, name, misc_name)

`m_librarian.db.` `update_counters`(pbar_cb=None)